@@ -137,11 +137,14 @@ MclustDA <- function(data, class, G = NULL, modelNames = NULL,
     Models <- rep(list(NULL), ncl)
     mc[[1]] <- as.name("mclustBIC")
     mc$class <- NULL
+    # noise <- eval(mc$initialization$noise, parent.frame())
     for(l in 1:ncl) 
        { I <- (class == classLabel[l])
          mc[[2]] <- data[I,]
          mc$G <- G[[l]]
          mc$modelNames <- as.character(modelNames[[l]])
+         # if(!is.null(noise))
+         #   mc$initialization$noise <- noise[I]
          if(verbose) cat(paste0("Class ", classLabel[l], ": "))
          BIC <- eval(mc, parent.frame())
          # slightly adjust parameters if none of the models can be fitted
@@ -220,7 +223,7 @@ summary.MclustDA <- function(object, parameters = FALSE, newdata, newclass, ...)
   ce <- mean(class != pred$classification)
   brier <- BrierScore(pred$z, class)
   tab <- try(table(class, pred$classification))
-  if(class(tab) == "try-error") 
+  if(inherits(tab, "try-error"))
     { ce <- tab <- NA }
   else 
     { names(dimnames(tab)) <- c("Class", "Predicted") }
@@ -904,8 +907,7 @@ plot.MclustDA <- function(x, what = c("scatterplot", "classification", "train&te
   
 }
 
-# TODO: delete
-# old version
+# TODO: old version to be deleted at a certain point
 # cvMclustDA <- function(object, nfold = 10, 
 #                        metric = c("error", "brier"), 
 #                        prop = object$prop,
@@ -981,7 +983,6 @@ plot.MclustDA <- function(x, what = c("scatterplot", "classification", "train&te
 #   return(out)
 # }
 
-# TODO: update man
 cvMclustDA <- function(object, nfold = 10, 
                        prop = object$prop,
                        verbose = interactive(), 
@@ -1043,12 +1044,15 @@ cvMclustDA <- function(object, nfold = 10,
       setTxtProgressBar(pbar, i)
   }
   #
-  cv <- apply(metric.cv, 2, function(m)
-              sum(m*folds.size)/sum(folds.size))
-  se <- apply(metric.cv, 2, function(m)
-              sqrt(var(m)/nfold))
+  cv <- sapply(1:2, function(m) sum(metric.cv[,m]*folds.size)/sum(folds.size))
+  # se <- apply(metric.cv, 2, function(m) sqrt(var(m)/nfold))
+  se <- sapply(1:2, function(m) 
+               sqrt( ( sum( (metric.cv[,m] - cv[m])^2 * folds.size) / 
+                       (sum(folds.size)*(nfold-1)/nfold)) / 
+                     nfold))
   #
-  out <- list(classification = class.cv, z = prob.cv,
+  out <- list(classification = class.cv, 
+		          z = prob.cv,
               ce = cv[1], se.ce = se[1],
               brier = cv[2], se.brier = se[2])
   return(out)
